###analysis communities

# Venn --------------------------------------------------------------------
### Venn diagram Figure S2
library(VennDiagram)
####venn diagram bacteria 5 blocks


grid.newpage()
draw.quintuple.venn(area1 = 610, area2 = 402, area3 = 427, area4 = 494, area5 = 473, 
                    n12 = 382, n13 = 398, n14 = 457, n15=437, n23 = 363, n24 = 366, n25= 353, 
                    n34 = 378, n35 = 374, n45 = 408, n123 = 354, n124 = 360, n125 = 350, 
                    n134 = 367, n135= 364, n145= 398, n234 = 340, n235 = 333, n245 = 341, 
                    n345= 352, n1234= 335, n1235= 331, n1245= 340, n1345=348, n2345= 323, 
                    n12345 = 322, 
                    category = c("NT", "FINI", "HII", "FII", "HINI"), 
                    lty = "blank", fill = c("green", "orange", "darkgreen", "yellow", "red"))


####venn diagram FUNGI 5 blocks

grid.newpage()
draw.quintuple.venn(area1 = 775, area2 = 298, area3 = 299, area4 = 320, area5 = 317, 
                    n12 = 298, n13 = 299, n14 = 320, n15=317, n23 = 206, n24 = 222, n25= 221, 
                    n34 = 217, n35 = 217, n45 = 214, n123 = 206, n124 = 222, n125 = 221, 
                    n134 = 217, n135= 217, n145= 214, n234 = 183, n235 = 182, n245 = 185, 
                    n345= 181, n1234= 183, n1235= 182, n1245= 185, n1345=181, n2345= 166, 
                    n12345 = 166, 
                    category = c("NT", "FINI", "HII", "FII", "HINI"), 
                    lty = "blank", fill = c("grey", "blue", "darkblue", "purple", "pink"))


# Alpha diversity ---------------------------------------------------------




###Alpha diversity analysis Figure 1

library("ggpubr")
library("ggplot2")
library("magrittr")
library(lme4)
library(lmerTest)
library(lsmeans)



###variable explained by treatments (fixed factors)+ replicate (random)
###  REML = F #because we want to compare models on likelihood

####Shannon indexes
df<-ALPHADIV
lmeModel = lmer(df$BH ~ df$TREATTIME + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)

lsmeans(lmeModel, pairwise~TREATTIME, adjust="Tukey")

lmeModel = lmer(df$FH ~ df$TREATTIME + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)

lsmeans(lmeModel, pairwise~TREATTIME, adjust="Tukey")


### Figure S3A PLOT

x<-ALPHADIV$BH
y<-ALPHADIV$FH


cor(x, y, method = c("pearson"))
cor.test(x, y, method=c("pearson"))

df<-ALPHADIV
x<-df$BH
y<-df$FH
ggscatter(ALPHADIV, x = 'BH', y = "FH", add = "reg.line", conf.int = TRUE, cor.coef = TRUE, cor.method = "pearson", xlab = "Bac Shannon", ylab = "Fun Shannon")

ggscatter(ALPHADIV, x = "BH", y = "FH", add = "reg.line", conf.int = TRUE, cor.coef = TRUE, cor.method = "pearson", xlab = "Bac Shannon", ylab = "Fun Shannon", color = "TREATTIME", palette = "jco", shape = "TREATTIME")       # Add correlation coefficient


########

####inverse of simpson 

lmeModel = lmer(df$BID ~ df$TREATTIME + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)

lsmeans(lmeModel, pairwise~TREATTIME, adjust="Tukey")

lmeModel = lmer(df$FID ~ df$TREATTIME + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)

lsmeans(lmeModel, pairwise~TREATTIME, adjust="Tukey")

### Figure S3B PLOT

x<-ALPHADIV$BID
y<-ALPHADIV$FID


cor(x, y, method = c("pearson"))
cor.test(x, y, method=c("pearson"))

df<-ALPHADIV
x<-df$BID
y<-df$FID
ggscatter(ALPHADIV, x = 'BID', y = "FID", add = "reg.line", conf.int = TRUE, cor.coef = TRUE, cor.method = "pearson", xlab = "Bac InverseSimpson", ylab = "Fun InverseSimpson")

ggscatter(ALPHADIV, x = "BID", y = "FID", add = "reg.line", conf.int = TRUE, cor.coef = TRUE, cor.method = "pearson", xlab = "Bac InverseSimpson", ylab = "Fun InverseSimpson", color = "TREATTIME", palette = "jco", shape = "TREATTIME")       # Add correlation coefficient


####SPECIES RICHNESS

lmeModel = lmer(df$B ~ df$TREATTIME + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)

lsmeans(lmeModel, pairwise~TREATTIME, adjust="Tukey")


lmeModel = lmer(df$F ~ df$TREATTIME + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)

lsmeans(lmeModel, pairwise~TREATTIME, adjust="Tukey")


# Beta diversity ----------------------------------------------------------



######BETA DIVERSITY


library(vegan)
library(ggplot2)

### get the data, BACPERM sheet
#bacteria

prebac.matrix<-as.matrix(VEG[,9:370]) ###species id BACTERIA


x<-as.factor(VEG$TREAT)


#STANDARIZE DATA

prebac.mat<-sqrt(prebac.matrix)#square root transform
prebac.dist<-vegdist(prebac.mat, method='bray') ###Bray-curtis dissimilarity

####PERMANOVA

prebac.div<-adonis2(prebac.dist~VEG$TREAT, data=VEG, permutations = 999, method="bray", strata="PLOT")
prebac.div


dispersion<-betadisper(prebac.dist, group=VEG$TREAT)
permutest(dispersion)
plot(dispersion, hull=FALSE, ellipse=TRUE) ##plot of PCoA
summary(eigenvals(dispersion))


####PLOTS
prebacMDS<-metaMDS(prebac.mat, distance="bray", k=2, trymax=35, autotransform=TRUE) ##k is the number of dimensions
prebacMDS ##metaMDS takes either a distance matrix or your community matrix (then requires method for 'distance=')

stressplot(prebacMDS) ###PLOT OF ordination distance vs. observed dissimilarity



##pull points from MDS
NMDS1 <- prebacMDS$points[,1] ##also found using scores
NMDS2 <- prebacMDS$points[,2]
prebac.plot<-cbind(VEG, NMDS1, NMDS2)

#plot ordination
p<-ggplot(prebac.plot, aes(NMDS1, NMDS2, color=VEG$TREAT))+
  geom_point(position=position_jitter(.1), shape=3)+##separates overlapping points
  stat_ellipse(type='t',size =1)+ ##draws 95% confidence interval ellipses
  theme_minimal()
p

#fungi FUNPERM sheet

prebac.matrix<-as.matrix(VEG[,9:193]) ###species id FUNGI

x<-as.factor(VEG$TREAT)


#STANDARIZE DATA

prebac.mat<-sqrt(prebac.matrix)#square root transform
prebac.dist<-vegdist(prebac.mat, method='bray') ###Bray-curtis dissimilarity

####PERMANOVA

prebac.div<-adonis2(prebac.dist~VEG$TREAT, data=VEG, permutations = 999, method="bray", strata="PLOT")
prebac.div


dispersion<-betadisper(prebac.dist, group=VEG$TREAT)
permutest(dispersion)
plot(dispersion, hull=FALSE, ellipse=TRUE) ##plot of PCoA
summary(eigenvals(dispersion))


####PLOTS
prebacMDS<-metaMDS(prebac.mat, distance="bray", k=2, trymax=35, autotransform=TRUE) ##k is the number of dimensions
prebacMDS ##metaMDS takes either a distance matrix or your community matrix (then requires method for 'distance=')

stressplot(prebacMDS) ###PLOT OF ordination distance vs. observed dissimilarity



##pull points from MDS
NMDS1 <- prebacMDS$points[,1] ##also found using scores
NMDS2 <- prebacMDS$points[,2]
prebac.plot<-cbind(VEG, NMDS1, NMDS2)

#plot ordination
p<-ggplot(prebac.plot, aes(NMDS1, NMDS2, color=VEG$TREAT))+
  geom_point(position=position_jitter(.1), shape=3)+##separates overlapping points
  stat_ellipse(type='t',size =1)+ ##draws 95% confidence interval ellipses
  theme_minimal()
p

# LMEM of clades  ---------------------------------------------------------

######
#######TAXA DISTRIBUTION PER TREATMENT AND TIME POINT

library(lme4)
library(lmerTest)
library(lsmeans)

###variable explained by treatments (fixed factors)+ time (random)
###  REML = F #because we want to compare models on likelihood

df<-ABUNDANCES ##bacteria phyla
colnames(df)

lmeModel = lmer(df$Acidobacteria ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Actinobacteria ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Armatimonadetes ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Bacteroidetes ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Chloroflexi ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Firmicutes ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Gemmatimonadetes ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Planctomycetes ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Proteobacteria ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Verrucomicrobia ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Others ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

df<-ABUNDANCES  #bacteria class

lmeModel = lmer(df$Actinobacteria ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Alphaproteobacteria ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Bacilli ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Betaproteobacteria ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Gammaproteobacteria ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Gemmatimonadetes ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Planctomycetia ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Rubrobacteria ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Solibacteres ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Spartobacteria ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Thaumarchaeota ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Thermoleophilia ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Others ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

######


df<-ABUNDANCES ##Fungi phyla
colnames(df)


lmeModel = lmer(df$Ascomycota ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Basidiomycota ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Zygomycota ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Others ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")


######


df<-ABUNDANCES ##Fungi CLASS
colnames(df)

lmeModel = lmer(df$Agaricomycetes ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Dothideomycetes ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Eurotiomycetes ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Leotiomycetes ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Pezizomycetes ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Saccharomycetes ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Sordariomycetes ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$Tremellomycetes ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")

lmeModel = lmer(df$others ~ df$treat + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~treat, adjust="Tukey")


# Cladograms --------------------------------------------------------------

### clades separated in different sheets.
####run this code for each bacterial and fungal phyla
View(VEG2)
View(VEG_SAMPLES)
### metacoder_ heat tree

library(metacoder)

summary(VEG2)
summary(VEG_SAMPLES)
VEG2$Taxon[1:4]
print(VEG2)
print(VEG_SAMPLES)


### veg2 1st column should be taxon, then, the samples with 1 or 0 (presence/absence)
###veg_samples with the info of the samples.

# Parse dataset for plotting
x <- parse_tax_data(VEG2, class_cols = "Taxon", class_sep = ";")


# Convert counts to proportions
x$data$otu_table <- calc_obs_props(x, data = "tax_data", cols = VEG_SAMPLES$sample)

# Get per-taxon counts
x$data$tax_table <- calc_taxon_abund(x, data = "otu_table", cols = VEG_SAMPLES$sample)

# Calculate difference between treatments
x$data$diff_table <- compare_groups(x, data = "tax_table",
                                    cols = VEG_SAMPLES$sample,
                                    groups = VEG_SAMPLES$Treat)

# Plot results (might take a few minutes)
heat_tree_matrix(x,
                 data = "diff_table",
                 node_size = n_obs,
                 node_label = taxon_names,
                 node_color = log2_median_ratio,
                 node_color_range = diverging_palette(),
                 node_color_trans = "linear",
                 node_color_interval = c(-3, 3),
                 edge_color_interval = c(-3, 3),
                 node_size_axis_label = "Number of OTUs",
                 node_color_axis_label = "Log2 ratio median proportions")



# Edaphic characteristics of soils ----------------------------------------

library(readxl)

soil_charact <- read_excel("F:/soil charact.xlsx", 
                             +     sheet = "soil")
View(soil_charact)
colnames(df)

lmeModel = lmer(df$pH ~ df$MYC*df$IRR + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~MYC*IRR, adjust="Tukey")

lmeModel = lmer(df$RH ~ df$MYC*df$IRR + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~MYC*IRR, adjust="Tukey")

lmeModel = lmer(df$Esoil ~ df$MYC*df$IRR + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~MYC*IRR, adjust="Tukey")

lmeModel = lmer(df$Tsurface ~ df$MYC*df$IRR + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~MYC*IRR, adjust="Tukey")

lmeModel = lmer(df$SWC ~ df$MYC*df$IRR + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~MYC*IRR, adjust="Tukey")

lmeModel = lmer(df$SBD ~ df$MYC*df$IRR + (1|df$rep), REML=F)
anova(lmeModel)
summary(lmeModel)
lsmeans(lmeModel, pairwise~MYC*IRR, adjust="Tukey")


# Canonical correspondence analysis ---------------------------------------
###Analysis + Figure 4

library(vegan)
library(labdsv)


###Bacteria

library(readxl)
CCA_ABUN <- read_excel("F:/CCA_ABUN.xlsx", 
                         +     sheet = "Bacteria")
View(CCA_ABUN)
###CCA analysis with bacterial abundances
bacteria.cca <- cca(CCA_ABUN ~ RH+pH+Esoil+Tsurface+SWC+SBD+SP, data=soil_charact)
bacteria.cca
anova(bacteria.cca)
plot(bacteria.cca)
summary(bacteria.cca)
points(bacteria.cca, pch= c (21, 21, 21, 21, 24, 24, 24, 24, 21,21,21,21,24,24,24, 24), col="blue", bg= c("cyan3", "cyan3", "cyan3", "cyan3","cyan3", "cyan3", "cyan3", "cyan3", "orange", "orange", "orange", "orange", "orange", "orange", "orange", "orange"), cex=1.0, )
legend("bottomright", legend=c("FINI", "FII", "HINI", "HII"), pch = c(21, 24, 21, 24), col = "blue", bg= c("cyan3", "cyan3", "orange", "orange"), cex=0.8)

###Fungi


CCA_ABUN <- read_excel("F:/CCA_ABUN.xlsx", 
                       +     sheet = "Fungi")
View(CCA_ABUN)
###CCA analysis with fungal abundances
fungal.cca <- cca(CCA_ABUN ~ RH+pH+Esoil+Tsurface+SWC+SBD+SP, data=soil_charact)
fungal.cca
anova(fungal.cca)
plot(fungal.cca)
summary(fungal.cca)
points(fungal.cca, pch= c (21, 21, 21, 21, 24, 24, 24, 24, 21,21,21,21,24,24,24, 24), col="blue", bg= c("cyan3", "cyan3", "cyan3", "cyan3","cyan3", "cyan3", "cyan3", "cyan3", "orange", "orange", "orange", "orange", "orange", "orange", "orange", "orange"), cex=1.0, )


# Co-occurrence networks --------------------------------------------------

library(visNetwork)
library(igraph)
library(cooccur)

VEG21 <- read_excel("F:/VEG21.xlsx", 
                    +     sheet = "VEG")
View(VEG21)

## Before treatment

T0<-cooccur((mat=VEG21[,2:17]), type="spp_site", thresh=T)
head(T0)
summary(T0)
T00<-print(T0)
plot(T0)

####network visualization

Acidobacteria <- (data.frame(id = 1:9, color = "#00CC99", shape = "circle", shadow = TRUE))
Actinobacteria <- (data.frame(id = 10:94, color = "#003300", shape = "circle", shadow = TRUE))
Bacteroidetes <- (data.frame(id = 95:123, color = "#FF3300", shape = "circle", shadow = TRUE))
Chloroflexi <- (data.frame(id = 124:133, color = "#FFFF00", shape = "circle", shadow = TRUE))
Firmicutes <- (data.frame(id = 134:200, color = "#66FFFF", shape = "circle", shadow = TRUE))
Planctomyces <- (data.frame(id = 201:209, color = "#FF00FF", shape = "circle", shadow = TRUE))
Proteobacteria <- (data.frame(id = 210:334, color = "#000099", shape = "circle", shadow = TRUE))
Verrumicrobia <- (data.frame(id = 335:343, color = "#CC0033", shape = "circle", shadow = TRUE))
Others <- (data.frame(id = 344:362, color = "#000000", shape = "circle", shadow = TRUE))
Ascomycota <- (data.frame(id = 363:493, color = "#999900", shape = "triangle", shadow = T))
Basidiomycota <- (data.frame(id = 494:528, color = "#993300", shape = "triangle", shadow = TRUE))
Zygomycota <- (data.frame(id = 529:540, color = "#003333", shape = "triangle", shadow = TRUE))


#########plot legend

##empty plot and then add legend
plot(NULL ,xaxt='n',yaxt='n',bty='n',ylab='',xlab='', xlim=0:1, ylim=0:1)

legend("topleft", legend=c('Bacteria', 'Acidobacteria','Actinobacteria', 'Bacteroidetes', 'Chloroflexi', 'Firmicutes', 'Planctomyces', 'Proteobacteria', 'Verrumicrobia', 'Others', 'Fungi','Ascomycota', 'Basidiomycota', 'Zygomycota'), col=c('#FFFFFF','#00CC99', '#003300','#FF3300','#FFFF00', '#66FFFF', '#FF00FF', '#000099', '#CC0033','#000000','#FFFFFF','#999900','#993300','#003333'),pch= c(16,16,16,16,16,16,16,16,16,16,17,17,17,17), pt.cex=3, cex=1.5, bty='n')

#nodes and edges and network
nodes<- rbind(Acidobacteria,Actinobacteria, Bacteroidetes, Chloroflexi, Firmicutes, Planctomyces, Proteobacteria, Verrumicrobia, Others, Ascomycota, Basidiomycota, Zygomycota)

edges <- data.frame (from = T00$sp1, to = T00$sp2, color= ifelse(T00$p_lt <= 0.05, "red", "grey"))

visNetwork(nodes = nodes, edges = edges) %>% visIgraphLayout("layout_with_sugiyama")


## After treatment

T1<-cooccur((mat=VEG21[,18:33]), type="spp_site", thresh=T)
head(T1)
summary(T1)
T11<-print(T1)
plot(T1)

####network visualization

Acidobacteria <- (data.frame(id = 1:9, color = "#00CC99", shape = "circle", shadow = TRUE))
Actinobacteria <- (data.frame(id = 10:94, color = "#003300", shape = "circle", shadow = TRUE))
Bacteroidetes <- (data.frame(id = 95:123, color = "#FF3300", shape = "circle", shadow = TRUE))
Chloroflexi <- (data.frame(id = 124:133, color = "#FFFF00", shape = "circle", shadow = TRUE))
Firmicutes <- (data.frame(id = 134:200, color = "#66FFFF", shape = "circle", shadow = TRUE))
Planctomyces <- (data.frame(id = 201:209, color = "#FF00FF", shape = "circle", shadow = TRUE))
Proteobacteria <- (data.frame(id = 210:334, color = "#000099", shape = "circle", shadow = TRUE))
Verrumicrobia <- (data.frame(id = 335:343, color = "#CC0033", shape = "circle", shadow = TRUE))
Others <- (data.frame(id = 344:362, color = "#000000", shape = "circle", shadow = TRUE))
Ascomycota <- (data.frame(id = 363:493, color = "#999900", shape = "triangle", shadow = T))
Basidiomycota <- (data.frame(id = 494:528, color = "#993300", shape = "triangle", shadow = TRUE))
Zygomycota <- (data.frame(id = 529:540, color = "#003333", shape = "triangle", shadow = TRUE))


nodes<- rbind(Acidobacteria,Actinobacteria, Bacteroidetes, Chloroflexi, Firmicutes, Planctomyces, Proteobacteria, Verrumicrobia, Others, Ascomycota, Basidiomycota, Zygomycota)

edges <- data.frame (from = T11$sp1, to = T11$sp2, color= ifelse(T11$p_lt <= 0.05, "red", "grey"))


visNetwork(nodes = nodes, edges = edges) %>% visIgraphLayout("layout_with_sugiyama")

###################
############
#################

## Before treatment bacteria

BAC0<-cooccur((mat=VEG21[1:362,2:17]), type="spp_site", thresh=T)
head(BAC0)
summary(BAC0)
BAC00<-print(BAC0)
plot(BAC0)

## Before treatment fungi

FUN0<-cooccur((mat=VEG21[363:540,2:17]), type="spp_site", thresh=T)
head(FUN0)
summary(FUN0)
FUN00<-print(FUN0)
plot(FUN0)


## after treatment bacteria

BAC1<-cooccur((mat=VEG21[1:362,18:33]), type="spp_site", thresh=T)
head(BAC1)
summary(BAC1)
BAC11<-print(BAC1)
plot(BAC1)

## after treatment fungi

FUN1<-cooccur((mat=VEG21[363:540,18:33]), type="spp_site", thresh=T)
head(FUN1)
summary(FUN1)
FUN11<-print(FUN1)
plot(FUN1)





# Co-occurrence Per treatments ----------------------------------------------------------

### FI

FI1<-cooccur((mat=VEG21[,18:25]), type="spp_site", thresh=T)
head(FI1)
summary(FI1)
FI11<-print(FI1)

### PLOT

####network visualization

Acidobacteria <- (data.frame(id = 1:9, color = "#00CC99", shape = "circle", shadow = TRUE))
Actinobacteria <- (data.frame(id = 10:94, color = "#003300", shape = "circle", shadow = TRUE))
Bacteroidetes <- (data.frame(id = 95:123, color = "#FF3300", shape = "circle", shadow = TRUE))
Chloroflexi <- (data.frame(id = 124:133, color = "#FFFF00", shape = "circle", shadow = TRUE))
Firmicutes <- (data.frame(id = 134:200, color = "#66FFFF", shape = "circle", shadow = TRUE))
Planctomyces <- (data.frame(id = 201:209, color = "#FF00FF", shape = "circle", shadow = TRUE))
Proteobacteria <- (data.frame(id = 210:334, color = "#000099", shape = "circle", shadow = TRUE))
Verrumicrobia <- (data.frame(id = 335:343, color = "#CC0033", shape = "circle", shadow = TRUE))
Others <- (data.frame(id = 344:362, color = "#000000", shape = "circle", shadow = TRUE))
Ascomycota <- (data.frame(id = 363:493, color = "#999900", shape = "triangle", shadow = T))
Basidiomycota <- (data.frame(id = 494:528, color = "#993300", shape = "triangle", shadow = TRUE))
Zygomycota <- (data.frame(id = 529:540, color = "#003333", shape = "triangle", shadow = TRUE))


nodes<- rbind(Acidobacteria,Actinobacteria, Bacteroidetes, Chloroflexi, Firmicutes, Planctomyces, Proteobacteria, Verrumicrobia, Others, Ascomycota, Basidiomycota, Zygomycota)


edges <- data.frame (from = FI11$sp1, to = FI11$sp2, color= ifelse(FI11$p_lt <= 0.05, "red", "grey"))
visNetwork(nodes = nodes, edges = edges) %>% visIgraphLayout("layout_in_circle")

###FI BACTERIA

FIbac1<-cooccur((mat=VEG21[1:362,18:25]), type="spp_site", thresh=T)
head(FIbac1)
summary(FIbac1)
FIbac11<-print(FIbac1)

### FI FUNGI

FIfun1<-cooccur((mat=VEG21[363:540,18:25]), type="spp_site", thresh=T)
head(FIfun1)
summary(FIfun1)
FIfun11<-print(FIfun1)


### HI

HI1<-cooccur((mat=VEG21[,26:33]), type="spp_site", thresh=T)
head(HI1)
summary(HINI1)
HI11<-print(HI1)

####network visualization

Acidobacteria <- (data.frame(id = 1:9, color = "#00CC99", shape = "circle", shadow = TRUE))
Actinobacteria <- (data.frame(id = 10:94, color = "#003300", shape = "circle", shadow = TRUE))
Bacteroidetes <- (data.frame(id = 95:123, color = "#FF3300", shape = "circle", shadow = TRUE))
Chloroflexi <- (data.frame(id = 124:133, color = "#FFFF00", shape = "circle", shadow = TRUE))
Firmicutes <- (data.frame(id = 134:200, color = "#66FFFF", shape = "circle", shadow = TRUE))
Planctomyces <- (data.frame(id = 201:209, color = "#FF00FF", shape = "circle", shadow = TRUE))
Proteobacteria <- (data.frame(id = 210:334, color = "#000099", shape = "circle", shadow = TRUE))
Verrumicrobia <- (data.frame(id = 335:343, color = "#CC0033", shape = "circle", shadow = TRUE))
Others <- (data.frame(id = 344:362, color = "#000000", shape = "circle", shadow = TRUE))
Ascomycota <- (data.frame(id = 363:493, color = "#999900", shape = "triangle", shadow = T))
Basidiomycota <- (data.frame(id = 494:528, color = "#993300", shape = "triangle", shadow = TRUE))
Zygomycota <- (data.frame(id = 529:540, color = "#003333", shape = "triangle", shadow = TRUE))


nodes<- rbind(Acidobacteria,Actinobacteria, Bacteroidetes, Chloroflexi, Firmicutes, Planctomyces, Proteobacteria, Verrumicrobia, Others, Ascomycota, Basidiomycota, Zygomycota)


edges <- data.frame (from = HI11$sp1, to = HI11$sp2, color= ifelse(HI11$p_lt <= 0.05, "red", "grey"))
visNetwork(nodes = nodes, edges = edges) %>% visIgraphLayout("layout_in_circle")

### HI BACTERIA

HIbac1<-cooccur((mat=VEG21[1:362,26:33]), type="spp_site", thresh=T)
head(HIbac1)
summary(HIbac1)
HINIbac11<-print(HIbac1)

### HI FUNGI

HIfun1<-cooccur((mat=VEG21[363:540,26:33]), type="spp_site", thresh=T)
head(HIfun1)
summary(HIfun1)
HIfun11<-print(HIfun1)

###################
####################
###############

### NI

NI1<-cooccur((mat=VEG21[,c(18:21,26:29)]), type="spp_site", thresh=T)
head(NI1)
summary(NI1)
NI11<-print(NI1)

####network visualization

Acidobacteria <- (data.frame(id = 1:9, color = "#00CC99", shape = "circle", shadow = TRUE))
Actinobacteria <- (data.frame(id = 10:94, color = "#003300", shape = "circle", shadow = TRUE))
Bacteroidetes <- (data.frame(id = 95:123, color = "#FF3300", shape = "circle", shadow = TRUE))
Chloroflexi <- (data.frame(id = 124:133, color = "#FFFF00", shape = "circle", shadow = TRUE))
Firmicutes <- (data.frame(id = 134:200, color = "#66FFFF", shape = "circle", shadow = TRUE))
Planctomyces <- (data.frame(id = 201:209, color = "#FF00FF", shape = "circle", shadow = TRUE))
Proteobacteria <- (data.frame(id = 210:334, color = "#000099", shape = "circle", shadow = TRUE))
Verrumicrobia <- (data.frame(id = 335:343, color = "#CC0033", shape = "circle", shadow = TRUE))
Others <- (data.frame(id = 344:362, color = "#000000", shape = "circle", shadow = TRUE))
Ascomycota <- (data.frame(id = 363:493, color = "#999900", shape = "triangle", shadow = T))
Basidiomycota <- (data.frame(id = 494:528, color = "#993300", shape = "triangle", shadow = TRUE))
Zygomycota <- (data.frame(id = 529:540, color = "#003333", shape = "triangle", shadow = TRUE))


nodes<- rbind(Acidobacteria,Actinobacteria, Bacteroidetes, Chloroflexi, Firmicutes, Planctomyces, Proteobacteria, Verrumicrobia, Others, Ascomycota, Basidiomycota, Zygomycota)


edges <- data.frame (from = NI11$sp1, to = NI11$sp2, color= ifelse(NI11$p_lt <= 0.05, "red", "grey"))
visNetwork(nodes = nodes, edges = edges) %>% visIgraphLayout("layout_in_circle")

### NI BACTERIA

NIbac1<-cooccur((mat=VEG21[1:362,c(18:21,26:29)]), type="spp_site", thresh=T)
head(NIbac1)
summary(NIbac1)
NIbac11<-print(NIbac1)

### NI FUNGI

NIfun1<-cooccur((mat=VEG21[363:540,c(18:21,26:29)]), type="spp_site", thresh=T)
head(NIfun1)
summary(NIfun1)
NIfun11<-print(NIfun1)


### I

I1<-cooccur((mat=VEG21[,c(22:25,30:33)]), type="spp_site", thresh=T)
head(I1)
summary(I1)
I11<-print(I1)

####network visualization

Acidobacteria <- (data.frame(id = 1:9, color = "#00CC99", shape = "circle", shadow = TRUE))
Actinobacteria <- (data.frame(id = 10:94, color = "#003300", shape = "circle", shadow = TRUE))
Bacteroidetes <- (data.frame(id = 95:123, color = "#FF3300", shape = "circle", shadow = TRUE))
Chloroflexi <- (data.frame(id = 124:133, color = "#FFFF00", shape = "circle", shadow = TRUE))
Firmicutes <- (data.frame(id = 134:200, color = "#66FFFF", shape = "circle", shadow = TRUE))
Planctomyces <- (data.frame(id = 201:209, color = "#FF00FF", shape = "circle", shadow = TRUE))
Proteobacteria <- (data.frame(id = 210:334, color = "#000099", shape = "circle", shadow = TRUE))
Verrumicrobia <- (data.frame(id = 335:343, color = "#CC0033", shape = "circle", shadow = TRUE))
Others <- (data.frame(id = 344:362, color = "#000000", shape = "circle", shadow = TRUE))
Ascomycota <- (data.frame(id = 363:493, color = "#999900", shape = "triangle", shadow = T))
Basidiomycota <- (data.frame(id = 494:528, color = "#993300", shape = "triangle", shadow = TRUE))
Zygomycota <- (data.frame(id = 529:540, color = "#003333", shape = "triangle", shadow = TRUE))


nodes<- rbind(Acidobacteria,Actinobacteria, Bacteroidetes, Chloroflexi, Firmicutes, Planctomyces, Proteobacteria, Verrumicrobia, Others, Ascomycota, Basidiomycota, Zygomycota)

edges <- data.frame (from = I11$sp1, to = I11$sp2, color= ifelse(I11$p_lt <= 0.05, "red", "grey"))
visNetwork(nodes = nodes, edges = edges) %>% visIgraphLayout("layout_in_circle")

### I BACTERIA

Ibac1<-cooccur((mat=VEG21[1:362,c(22:25,30:33)]), type="spp_site", thresh=T)
head(Ibac1)
summary(Ibac1)
Ibac11<-print(Ibac1)

### I FUNGI

Ifun1<-cooccur((mat=VEG21[363:540,c(22:25,30:33)]), type="spp_site", thresh=T)
head(Ifun1)
summary(Ifun1)
NIfun11<-print(Ifun1)

